---
name: "\U0001F6A8 Submit a Bug Report"
about: Use this template if you came across a bug or unexpected behaviour differing from the docs.
labels: bug
---

## How to reproduce the behaviour
<!-- Include a code example or the steps that led to the problem. Please try to be as specific as possible. -->

## Your Environment
<!-- Include details of your environment. To get the version of textdescriptives you can get use `python -c "import textdescriptives as td; print(td.__version__)"`.-->
* textdescriptives Version Used:
* Operating System:
* Python Version Used: